Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
Types ¶
type Bst ¶
type Bst struct {
// contains filtered or unexported fields
}
Bst is a structure format is designed for small structures. It contains the actual structure information, along with the blocks inside the structure. It is very similar to the legacy schematic format.
func New ¶
New creates a new Bst and initialises it with air blocks. The Bst returned may be written to using Bst.Set and read using Bst.At..
func (*Bst) Dimensions ¶
Dimensions returns the bounds of the Bst.
Click to show internal directories.
Click to hide internal directories.